@@ -30,7 +30,7 @@ class Route:
 
     @property
     def description(self):
-        return self._description
+        return self.description
 
     @property
     def source(self):
@@ -53,8 +53,8 @@ class Route:
         return self._extensions
 
     @property
-    def points(self):
-        return self._points
+    def segments(self):
+        return self.segments
 
 
 
